@@ -7,10 +7,11 @@ import matplotlib.transforms
 import numpy as np
 import spiceypy as spice
 from matplotlib.axes import Axes
-from spiceypy.utils.exceptions import NotFoundError
+from spiceypy.utils.exceptions import NotFoundError, SpiceKERNELVARNOTFOUND
 
 from . import data_loader, utils
 from .base import SpiceBase, Numeric
+from .basic_body import BasicBody
 
 
 class Body(SpiceBase):
@@ -23,7 +24,7 @@ class Body(SpiceBase):
     that are passed to SPICE functions which can almost always be left as their default
     values. See the
     `SPICE documentation <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/subpnt_c.html#Detailed_Input>`_
-    for more details about possible parameter values. 
+    for more details about possible parameter values.
 
     The `target` and `observer` names are passed to
     :func:`SpiceBase.standardise_body_name`, so a variety of formats are acceptable. For
@@ -40,16 +41,18 @@ class Body(SpiceBase):
             `string` datetime representation compatible with SPICE (e.g.
             `'2000-12-31T23:59:59'` - see the
             `documentation of acceptable string formats <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/utc2et_c.html>`_),
-            a Python `datetime` object, or a `float` representing the Modified Julian 
+            a Python `datetime` object, or a `float` representing the Modified Julian
             Date (MJD) of the observation. Alternatively, if `utc` is `None` (the
             default), then the current time is used.
         observer: Name of observing body. Defaults to `'EARTH'`.
+        aberration_correction: Aberration correction used to correct light travel time
+            in SPICE. Defaults to `'CN'`.
         observer_frame: Observer reference frame. Defaults to `'J2000'`,
         illumination_source: Illumination source. Defaults to `'SUN'`.
-        aberration_correction: Aberration correction used to correct light travel time
-            in SPICE.
         subpoint_method: Method used to calculate the sub-observer point in SPICE.
-        surface_method: Method used to calculate surface intercepts in SPICE.
+            Defaults to `'INTERCEPT/ELLIPSOID'`.
+        surface_method: Method used to calculate surface intercepts in SPICE. Defaults
+            to `'ELLIPSOID'`.
         **kwargs: Additional arguments are passed to :class:`SpiceBase`.
     """
 
@@ -59,9 +62,9 @@ class Body(SpiceBase):
         utc: str | datetime.datetime | float | None = None,
         observer: str | int = 'EARTH',
         *,
+        aberration_correction: str = 'CN',
         observer_frame: str = 'J2000',
         illumination_source: str = 'SUN',
-        aberration_correction: str = 'CN+S',
         subpoint_method: str = 'INTERCEPT/ELLIPSOID',
         surface_method: str = 'ELLIPSOID',
         **kwargs,
@@ -112,33 +115,45 @@ class Body(SpiceBase):
         """Longitude of the sub-observer point on the target."""
         self.subpoint_lat: float
         """Latitude of the sub-observer point on the target."""
+        self.named_ring_data: dict[str, list[float]]
+        """
+        Dictionary of ring radii for the target from :func:`data_loader.get_ring_radii`.
+
+        The dictionary keys are the names of the rings, and values are list of ring 
+        radii in km. If the length of this list is 2, then the values give the inner and 
+        outer radii of the ring respectively. Otherwise, the length should be 1, meaning
+        the ring has a single radius. These ring radii values are sourced from
+        `planetary factsheets <https://nssdc.gsfc.nasa.gov/planetary/planetfact.html>`_.
+        If no ring data is available for the target, this dictionary is empty.
+
+        Values from this dictionary can be easily accessed using the convenience
+        function :func:`ring_radii_from_name`.
+        """
         self.ring_radii: set[float]
         """
         Set of ring radii in km to plot around the target body's equator. Each radius
         is plotted as a single line, so for a wide ring you may want to add both the
         inner and outer edger of the ring. The radii are defined as the distance from
         the centre of the target body to the ring. For Saturn, the A, B and C rings from
-        https://nssdc.gsfc.nasa.gov/planetary/factsheet/satringfact.html are included by
-        default. For all other bodies, `ring_radii` is empty by default.
+        :attr:`named_ring_data` are included by default. For all other bodies,
+        `ring_radii` is empty by default.
 
-        Ring radii data from the 
-        `planetary factsheets <https://nssdc.gsfc.nasa.gov/planetary/planetfact.html>`_ 
-        can be loaded using :func:`data_loader.get_ring_radii`.
-        
-        Example usage: ::
+        Ring radii data from the :attr:`named_ring_data` can easily be added to 
+        `ring_radii` using :func:`add_named_rings`. Example usage: ::
 
             body.ring_radii.add(122340) # Add new ring radius to plot
             body.ring_radii.add(136780) # Add new ring radius to plot
-            body.ring_radii.update([66900, 74510]) # Add multiple radii to plot once
+            body.ring_radii.update([66900, 74510]) # Add multiple radii to plot at once
 
             body.ring_radii.remove(122340) # Remove a ring radius
             body.ring_radii.clear() # Remove all ring radii
 
-            # Add ring radii using data from planetary factsheets
-            ring_data = planetmapper.data_loader.get_ring_radii()['JUPITER']
-            body.ring_radii.update(ring_data['Main Ring'])
-            body.ring_radii.update(ring_data['Amalthea Ring'])
-        
+            # Add specific ring radii using data from planetary factsheets
+            body.add_named_rings('main', 'halo')
+
+            # Add all rings defined in the planetary factsheets
+            body.add_named_rings()
+
         See also :func:`ring_radec`.
         """
         self.coordinates_of_interest_lonlat: list[tuple[float, float]]
@@ -157,7 +172,7 @@ class Body(SpiceBase):
 
             body.coordinates_of_interest_radec.append((200, -45))
         """
-        self.other_bodies_of_interest: list[Body]
+        self.other_bodies_of_interest: list[Body | BasicBody]
         """
         List of other bodies of interest to mark when plotting. Add to this list using 
         :func:`add_other_bodies_of_interest`.
@@ -259,6 +274,17 @@ class Body(SpiceBase):
             *self._obsvec2radec_radians(self._subpoint_obsvec)
         )
 
+        # Set up equatorial plane (for ring calculations)
+        targvec_north_pole = self.lonlat2targvec(0, 90)
+        obsvec_north_pole = self._targvec2obsvec(targvec_north_pole)
+        self._ring_plane = spice.nvp2pl(
+            obsvec_north_pole - self._target_obsvec,
+            self._target_obsvec,
+        )
+
+        # Load additional data
+        self.named_ring_data = data_loader.get_ring_radii().get(self.target, {})
+
         # Create empty lists/blank values
         self.ring_radii = set()
         self.other_bodies_of_interest = []
@@ -274,15 +300,16 @@ class Body(SpiceBase):
 
         # Run custom setup
         if self.target == 'SATURN':
-            ring_data = data_loader.get_ring_radii()['SATURN']
             for k in ['A', 'B', 'C']:
-                for r in ring_data.get(k, []):
+                for r in self.named_ring_data.get(k, []):
                     self.ring_radii.add(r)
 
     def __repr__(self) -> str:
         return f'Body({self.target!r}, {self.utc!r})'
 
-    def create_other_body(self, other_target: str|int) -> 'Body':
+    def create_other_body(
+        self, other_target: str | int, fallback_to_basic_body: bool = True
+    ) -> 'Body|BasicBody':
         """
         Create a :class:`Body` instance using identical parameters but just with a
         different target. For example, the `europa` body created here will have
@@ -296,24 +323,44 @@ class Body(SpiceBase):
         `illumination_source`, `aberration_correction`, `subpoint_method`, and
         `surface_method`.
 
+        If a full :class:`Body` instance cannot be created due to insufficient data in
+        the SPICE kernel, a :class:`BasicBody` instance will be created instead. This is
+        useful for objects such as minor satellites which do not have known radius data.
+
         Args:
             other_target: Name of the other target, passed to :class:`Body`
+            fallback_to_basic_body: If a full :class:`Body` instance cannot be created
+                due to insufficient data in the SPICE kernel, attempt to create a
+                :class:`BasicBody` instance instead.
 
         Returns:
-            :class:`Body` instance which corresponds to `other_target`.
+            :class:`Body` or :class:`BasicBody` instance which corresponds to
+            `other_target`.
         """
-        return Body(
-            target=other_target,
-            utc=self.utc,
-            observer=self.observer,
-            observer_frame=self.observer_frame,
-            illumination_source=self.illumination_source,
-            aberration_correction=self.aberration_correction,
-            subpoint_method=self.subpoint_method,
-            surface_method=self.surface_method,
-        )
+        try:
+            return Body(
+                target=other_target,
+                utc=self.utc,
+                observer=self.observer,
+                observer_frame=self.observer_frame,
+                illumination_source=self.illumination_source,
+                aberration_correction=self.aberration_correction,
+                subpoint_method=self.subpoint_method,
+                surface_method=self.surface_method,
+            )
+        except SpiceKERNELVARNOTFOUND:
+            if not fallback_to_basic_body:
+                raise
+            return BasicBody(
+                target=other_target,
+                utc=self.utc,
+                observer=self.observer,
+                observer_frame=self.observer_frame,
+                aberration_correction=self.aberration_correction,
+            )
 
-    def add_other_bodies_of_interest(self, *other_targets: str|int):
+    # Stuff to customise wireframe plots
+    def add_other_bodies_of_interest(self, *other_targets: str | int) -> None:
         """
         Add targets to the list of :attr:`other_bodies_of_interest` of interest to mark
         when plotting. The other targets are created using :func:`create_other_body`.
@@ -329,7 +376,9 @@ class Body(SpiceBase):
             body = planetmapper.Body('Uranus')
             body.add_other_bodies_of_interest(*range(701, 711))
             # Uranus' satellites have ID codes 701, 702, 703 etc, so this adds 10 moons
-            # with a single function call 
+            # with a single function call
+
+        See also :func:`add_satellites_to_bodies_of_interest`.
 
         Args:
             *other_targets: Names of the other targets, passed to :class:`Body`
@@ -337,6 +386,70 @@ class Body(SpiceBase):
         for other_target in other_targets:
             self.other_bodies_of_interest.append(self.create_other_body(other_target))
 
+    def add_satellites_to_bodies_of_interest(self) -> None:
+        """
+        Automatically add all satellites in the target planetary system to
+        :attr:`other_bodies_of_interest`.
+
+        This uses the NAIF ID codes to identify the satellites. For example, Uranus has
+        an ID of 799, and its satellites have codes 701, 702, 703..., so any object with
+        a code in the range 701 to 798 is added for Uranus.
+
+        See also :func:`add_other_bodies_of_interest`.
+        """
+        id_base = (self.target_body_id // 100) * 100
+        for other_target in range(id_base + 1, id_base + 99):
+            try:
+                self.other_bodies_of_interest.append(
+                    self.create_other_body(other_target)
+                )
+            except NotFoundError:
+                continue
+
+    def ring_radii_from_name(self, name: str) -> list[float]:
+        """
+        Get list of ring radii in km for a named ring.
+
+        This is a convenience function to load data from :attr:`named_ring_data`.
+
+        Args:
+            name: Name of ring. This is case insensitive.
+
+        Raises:
+            ValueError: if no ring with the provided name is found.
+
+        Returns:
+            List of ring radii in km. If the length of this list is 2, then the values
+            give the inner and outer radii of the ring respectively. Otherwise, the
+            length should be 1, meaning the ring has a single radius.
+        """
+        standardise = lambda name: name.casefold().strip().removesuffix('ring').strip()
+        name = standardise(name.casefold().strip())
+        for n, radii in self.named_ring_data.items():
+            if name == standardise(n):
+                return radii
+        raise ValueError(f'No rings found named {name!r} in named_ring_data')
+
+    def add_named_rings(self, *names: str) -> None:
+        """
+        Add named rings to :attr:`ring_radii` so that they appear when creating
+        wireframe plots. If no arguments are provided (i.e. calling
+        `body.add_named_rings()`), then all rings in :attr:`named_ring_data` are added
+        to :attr:`ring_radii`.
+
+        This is a convenience function to add data from :attr:`named_ring_data` to
+        :attr:`ring_radii`.
+
+        Args:
+            *names: Ring names which are passed to :func:`ring_radii_from_name`. If
+                no names are provided then all rings in :attr:`named_ring_data` are
+                added.
+        """
+        if len(names) == 0:
+            names = tuple(self.named_ring_data.keys())
+        for name in names:
+            self.ring_radii.update(self.ring_radii_from_name(name))
+
     # Coordinate transformations target -> observer direction
     def _lonlat2targvec_radians(
         self, lon: float, lat: float, alt: float = 0
@@ -412,6 +525,44 @@ class Body(SpiceBase):
     def _radec2obsvec_norm_radians(self, ra: float, dec: float) -> np.ndarray:
         return spice.radrec(1, ra, dec)
 
+    def _obsvec2targvec(self, obsvec: np.ndarray) -> np.ndarray:
+        """
+        Transform rectangular vector in observer frame to rectangular vector in target
+        frame.
+
+        Based on inverse of _targvec2obsvec
+        """
+
+        # Get the target vector from the subpoint to the point of interest
+        obsvec_offset = obsvec - self._subpoint_obsvec  # type: ignore
+        # ^ ignoring type warning due to numpy bug (TODO remove type: ingore in future)
+        # https://github.com/numpy/numpy/issues/22437
+
+        # Calculate the difference in LOS distance between observer<->subpoint and
+        # observer<->point of interest
+        dist_offset = (
+            np.linalg.norm(-self._subpoint_rayvec + obsvec_offset)
+            - self.subpoint_distance
+        )
+
+        # Use the calculated difference in distance relative to the subpoint to
+        # calculate the time corresponding to when the ray left the surface at the point
+        # of interest
+        obsvec_et = self._subpoint_et - dist_offset / self.speed_of_light()
+
+        # Create the transform matrix converting between the target vector at the time
+        # the ray left the point of interest -> the observer vector at the time the ray
+        # hit the detector
+        transform_matrix = spice.pxfrm2(
+            self._observer_frame_encoded,  # type: ignore
+            self._target_frame_encoded,  # type: ignore
+            self.et,
+            obsvec_et,
+        )
+
+        # Use the transform matrix to perform the actual transformation
+        return self._subpoint_targvec + np.matmul(transform_matrix, obsvec_offset)
+
     def _obsvec_norm2targvec(self, obsvec_norm: np.ndarray) -> np.ndarray:
         """TODO add note about raising NotFoundError"""
         spoint, trgepc, srfvec = spice.sincpt(
@@ -627,7 +778,7 @@ class Body(SpiceBase):
 
     def radec2km(self, ra: float, dec: float) -> tuple[float, float]:
         """
-        Convert RA/Dec sky coordinates for the observer to distances in the target 
+        Convert RA/Dec sky coordinates for the observer to distances in the target
         plane.
 
         Args:
@@ -840,7 +991,7 @@ class Body(SpiceBase):
     ) -> Numeric:
         # Based on Henrik's code at:
         # https://github.com/JWSTGiantPlanets/NIRSPEC-Toolkit/blob/5e2e2cc/JWSTSolarSystemPointing.py#L204-L209
-        a = np.cos(phase_radians) - np.cos(emission_radians) * np.cos(incidence_radians)
+        a = np.cos(phase_radians) - np.cos(emission_radians) * np.cos(incidence_radians)  # type: ignore
         b = np.sqrt(1.0 - np.cos(emission_radians) ** 2) * np.sqrt(
             1.0 - np.cos(incidence_radians) ** 2
         )
@@ -932,6 +1083,146 @@ class Body(SpiceBase):
         """
         return self._test_if_targvec_illuminated(self.lonlat2targvec(lon, lat))
 
+    # Rings
+    def _ring_coordinates_from_obsvec(
+        self, obsvec: np.ndarray, only_visible: bool = True
+    ) -> tuple[float, float, float]:
+        nxpts, intercept_obsvec = spice.inrypl(
+            np.array([0, 0, 0]), obsvec, self._ring_plane
+        )
+        if nxpts != 1:
+            return np.nan, np.nan, np.nan
+        targvec = self._obsvec2targvec(intercept_obsvec)
+        lon, lat, alt = spice.recpgr(
+            self._target_encoded,  # type: ignore
+            targvec,
+            self.r_eq,
+            self.flattening,
+        )
+        if only_visible and alt < 0:
+            return np.nan, np.nan, np.nan
+
+        distance = self.vector_magnitude(intercept_obsvec)
+        if only_visible:
+            try:
+                position, velocity, lt = self._state_from_targvec(
+                    self._obsvec_norm2targvec(obsvec)
+                )
+                surface_distance = lt * self.speed_of_light()
+                if surface_distance < distance:
+                    return np.nan, np.nan, np.nan
+            except NotFoundError:
+                pass
+
+        lon = np.rad2deg(lon)
+        radius = alt + self.r_eq
+        return radius, lon, distance
+
+    def ring_plane_coordinates(
+        self, ra: float, dec: float, only_visible: bool = True
+    ) -> tuple[float, float, float]:
+        """
+        Calculate coordinates in the target body's equatorial (ring) plane. This is
+        mainly useful for calculating the coordinates in a body's ring system at a given
+        point in the sky.
+
+        To calculate the coordinates corresponding to a location on the target body, you
+        can use ::
+
+            body.ring_plane_coordinates(*body.radec2lonlat(lon, lat))
+
+        This form can be useful to identify parts of a planet's surface which are
+        obscured by its rings ::
+
+            radius, _, _ = body.ring_plane_coordinates(*body.lonlat2radec(lon, lat))
+            ring_data = planetmapper.data_loader.get_ring_radii()['SATURN']
+            for name, radii in ring_data.items():
+                if min(radii) < radius < max(radii):
+                    print(f'Point obscured by {name} ring')
+                    break
+            else:
+                print('Point not obscured by rings')
+
+        Args:
+            ra: Right ascension of point in the sky of the observer.
+            dec: Declination of point in the sky of the observer.
+            only_visible: If `True` (the default), coordinates for parts of the
+                equatorial plane hidden behind the target body are set to NaN.
+
+        Returns:
+            `(ring_radius, ring_longitude, ring_distance)` tuple for the point on the
+            target body's equatorial (ring) plane. `ring_radius` gives the distance of
+            the point in km from the centre of the target body. `ring_longitude` gives
+            the planetographic longitude of the point in degrees. `ring_distance` gives
+            the distance from the observer to the point in km.
+        """
+        return self._ring_coordinates_from_obsvec(
+            self._radec2obsvec_norm_radians(*self._degree_pair2radians(ra, dec)),
+            only_visible=only_visible,
+        )
+
+    def ring_radec(
+        self, radius: float, npts: int = 360, only_visible: bool = True
+    ) -> tuple[np.ndarray, np.ndarray]:
+        """
+        Calculate RA/Dec coordinates of a ring around the target body.
+
+        The ring is assumed to be directly above the planet's equator and has a constant
+        `radius` for all longitudes. Use :attr:`ring_radii` to set the rings
+        automatically plotted.
+
+        Args:
+            radius: Radius in km of the ring from the centre of the target body.
+            npts: Number of points in the generated ring.
+            only_visible: If `True` (default), the coordinates for the part of the ring
+                hidden behind the target body are set to NaN. This routine will execute
+                slightly faster with `only_visible` set to `False`.
+
+        Returns:
+            `(ra, dec)` tuple of coordinate arrays.
+        """
+        lons = np.deg2rad(np.linspace(0, 360, npts))
+        alt = radius - self.r_eq
+        targvecs = [self._lonlat2targvec_radians(lon, 0, alt) for lon in lons]
+        obsvecs = [self._targvec2obsvec(targvec) for targvec in targvecs]
+
+        ra_arr = np.full(npts, np.nan)
+        dec_arr = np.full(npts, np.nan)
+        for idx, obsvec in enumerate(obsvecs):
+            if only_visible:
+                # Test the obsvec ray from the observer to this point on the ring to see
+                # if it has a surface intercept with the target body. If there is no
+                # intercept (NotFoundError), then this ring point is definitely visible.
+                # If there is surface intercept, then we see if the ring point is closer
+                # to the observer than the target body's centre (=> this ring point is
+                # visible) or if the ring is behind the target body (=> this ring point
+                # is hidden).
+                try:
+                    spice.sincpt(
+                        self._surface_method_encoded,
+                        self._target_encoded,
+                        self.et,
+                        self._target_frame_encoded,
+                        self._aberration_correction_encoded,
+                        self._observer_encoded,
+                        self._observer_frame_encoded,
+                        obsvec,
+                    )
+                    # If we reach this point then the ring is either infront/behind the
+                    # target body.
+                    if self.vector_magnitude(obsvec) > self.target_distance:
+                        # This part of the ring is hidden behind the target, so leave
+                        # the output array values as NaN.
+                        continue
+                except NotFoundError:
+                    # Ring is to the side of the target body, so is definitely visible,
+                    # so continue with the coordinate conversion for this point.
+                    pass
+            ra_arr[idx], dec_arr[idx] = self._radian_pair2degrees(
+                *self._obsvec2radec_radians(obsvec)
+            )
+        return ra_arr, dec_arr
+
     # Lonlat grid
     def visible_lonlat_grid_radec(
         self, interval: float = 30, **kwargs
@@ -1063,67 +1354,19 @@ class Body(SpiceBase):
         """
         return self._radial_velocity_from_targvec(self.lonlat2targvec(lon, lat))
 
-    def ring_radec(
-        self, radius: float, npts: int = 360, only_visible: bool = True
-    ) -> tuple[np.ndarray, np.ndarray]:
+    def distance_from_lonlat(self, lon: float, lat: float) -> float:
         """
-        Calculate RA/Dec coordinates of a ring around the target body.
-
-        The ring is assumed to be directly above the planet's equator and has a constant
-        `radius` for all longitudes. Use :attr:`ring_radii` to set the rings
-        automatically plotted.
+        Calculate distance from observer to a point on the target's surface.
 
         Args:
-            radius: Radius in km of the ring from the centre of the target body.
-            npts: Number of points in the generated ring.
-            only_visible: If `True` (default), the coordinates for the part of the ring
-                hidden behind the target body are set to NaN. This routine will execute
-                slightly faster with `only_visible` set to `False`.
+            lon: Longitude of point on target body.
+            lat: Latitude of point on target body.
 
         Returns:
-            `(ra, dec)` tuple of coordinate arrays.
+            Distance of the point in km.
         """
-        lons = np.deg2rad(np.linspace(0, 360, npts))
-        alt = radius - self.r_eq
-        targvecs = [self._lonlat2targvec_radians(lon, 0, alt) for lon in lons]
-        obsvecs = [self._targvec2obsvec(targvec) for targvec in targvecs]
-
-        ra_arr = np.full(npts, np.nan)
-        dec_arr = np.full(npts, np.nan)
-        for idx, obsvec in enumerate(obsvecs):
-            if only_visible:
-                # Test the obsvec ray from the observer to this point on the ring to see
-                # if it has a surface intercept with the target body. If there is no
-                # intercept (NotFoundError), then this ring point is definitely visible.
-                # If there is surface intercept, then we see if the ring point is closer
-                # to the observer than the target body's centre (=> this ring point is
-                # visible) or if the ring is behind the target body (=> this ring point
-                # is hidden).
-                try:
-                    spice.sincpt(
-                        self._surface_method_encoded,
-                        self._target_encoded,
-                        self.et,
-                        self._target_frame_encoded,
-                        self._aberration_correction_encoded,
-                        self._observer_encoded,
-                        self._observer_frame_encoded,
-                        obsvec,
-                    )
-                    # If we reach this point then the ring is either infront/behind the
-                    # target body.
-                    if self.vector_magnitude(obsvec) > self.target_distance:
-                        # This part of the ring is hidden behind the target, so leave
-                        # the output array values as NaN.
-                        continue
-                except NotFoundError:
-                    # Ring is to the side of the target body, so is definitely visible,
-                    # so continue with the coordinate conversion for this point.
-                    pass
-            ra_arr[idx], dec_arr[idx] = self._radian_pair2degrees(
-                *self._obsvec2radec_radians(obsvec)
-            )
-        return ra_arr, dec_arr
+        position, velocity, lt = self._state_from_targvec(self.lonlat2targvec(lon, lat))
+        return lt * self.speed_of_light()
 
     # Planetographic <-> planetocentric
     def _targvec2lonlat_centric(self, targvec: np.ndarray) -> tuple[float, float]:
@@ -1233,6 +1476,7 @@ class Body(SpiceBase):
         ax: Axes | None = None,
         color: str | tuple[float, float, float] = 'k',
         label_poles: bool = True,
+        add_title: bool = True,
         **kwargs,
     ) -> Axes:
         """Plot generic wireframe representation of the observation"""
@@ -1343,7 +1587,8 @@ class Body(SpiceBase):
                 transform=transform,
                 **kwargs,
             )
-        ax.set_title(self.get_description(multiline=True))
+        if add_title:
+            ax.set_title(self.get_description(multiline=True))
         return ax
 
     def plot_wireframe_radec(
@@ -1352,6 +1597,9 @@ class Body(SpiceBase):
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
         label_poles: bool = True,
+        add_title: bool = True,
+        add_axis_labels: bool = True,
+        aspect_adjustable: Literal['box', 'datalim'] = 'datalim',
         dms_ticks: bool = True,
         **kwargs,
     ) -> Axes:
@@ -1365,6 +1613,10 @@ class Body(SpiceBase):
             show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
             label_poles: Toggle labelling the poles of the target body.
+            add_title: Add title generated by :func:`get_description` to the axis.
+            add_axis_labels: Add axis labels.
+            aspect_adjustable: Set `adjustable` parameter when setting the aspect ratio.
+                Passed to :func:`matplotlib.axes.Axes.set_aspect`.
             dms_ticks: Toggle between showing ticks as degrees, minutes and seconds
                 (e.g. 12°34′56″) or decimal degrees (e.g. 12.582).
             **kwargs: Additional arguments are passed to Matplotlib plotting functions
@@ -1374,10 +1626,21 @@ class Body(SpiceBase):
             The axis containing the plotted wireframe.
         """
         ax = self._plot_wireframe(
-            transform=None, ax=ax, color=color, label_poles=label_poles, **kwargs
+            transform=None,
+            ax=ax,
+            color=color,
+            label_poles=label_poles,
+            add_title=add_title,
+            **kwargs,
         )
 
-        utils.format_radec_axes(ax, self.target_dec, dms_ticks)
+        utils.format_radec_axes(
+            ax,
+            self.target_dec,
+            dms_ticks=dms_ticks,
+            add_axis_labels=add_axis_labels,
+            aspect_adjustable=aspect_adjustable,
+        )
 
         if show:
             plt.show()
@@ -1389,6 +1652,9 @@ class Body(SpiceBase):
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
         label_poles: bool = True,
+        add_title: bool = True,
+        add_axis_labels: bool = True,
+        aspect_adjustable: Literal['box', 'datalim'] = 'datalim',
         **kwargs,
     ) -> Axes:
         """
@@ -1401,6 +1667,10 @@ class Body(SpiceBase):
             show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
             label_poles: Toggle labelling the poles of the target body.
+            add_title: Add title generated by :func:`get_description` to the axis.
+            add_axis_labels: Add axis labels.
+            aspect_adjustable: Set `adjustable` parameter when setting the aspect ratio.
+                Passed to :func:`matplotlib.axes.Axes.set_aspect`.
             **kwargs: Additional arguments are passed to Matplotlib plotting functions
                 (useful for e.g. specifying `zorder`).
 
@@ -1410,13 +1680,18 @@ class Body(SpiceBase):
 
         transform = self.matplotlib_radec2km_transform()
         ax = self._plot_wireframe(
-            transform=transform, ax=ax, color=color, label_poles=label_poles, **kwargs
+            transform=transform,
+            ax=ax,
+            color=color,
+            label_poles=label_poles,
+            add_title=add_title,
+            **kwargs,
         )
-
-        ax.set_xlabel('Projected distance (km)')
-        ax.set_ylabel('Projected distance (km)')
-        ax.ticklabel_format(style='sci', scilimits=(-3, 3))
-        ax.set_aspect(1, adjustable='datalim')
+        if add_axis_labels:
+            ax.set_xlabel('Projected distance (km)')
+            ax.set_ylabel('Projected distance (km)')
+            ax.ticklabel_format(style='sci', scilimits=(-3, 3))
+        ax.set_aspect(1, adjustable=aspect_adjustable)
 
         if show:
             plt.show()
