@@ -10,6 +10,7 @@ from typing import (
     ParamSpec,
     Protocol,
     TypeVar,
+    Literal,
 )
 import warnings
 
@@ -272,9 +273,7 @@ class BodyXY(Body):
 
         if self._nx > 0 and self._ny > 0:
             # centre disc if dimensions provided
-            self._x0 = self._nx / 2 - 0.5
-            self._y0 = self._ny / 2 - 0.5
-            self._r0 = 0.9 * (min(self._x0, self._y0))
+            self.centre_disc()
 
         self._mpl_transform_radec2xy: matplotlib.transforms.Affine2D | None = None
         self._mpl_transform_xy2radec: matplotlib.transforms.Transform | None = None
@@ -469,6 +468,20 @@ class BodyXY(Body):
         """
         return self.get_x0(), self.get_y0(), self.get_r0(), self.get_rotation()
 
+    def centre_disc(self) -> None:
+        """
+        Centre the target's planetary disc and make it fill ~90% of the observation.
+
+        This adjusts `x0` and `y0` so that they lie in the centre of the image, and `r0`
+        is adjusted so that the disc fills 90% of the shortest side of the image. For
+        example, if `nx = 20` and `ny = 30`, then `x0` will be set to 10, `y0` will be
+        set to 15 and `r0` will be set to 9. The rotation of the disc is unchanged.
+        """
+        self.set_x0(self._nx / 2)
+        self.set_y0(self._ny / 2)
+        self.set_r0(0.9 * (min(self.get_x0(), self.get_y0())))
+        self.set_disc_method('centre_disc')
+
     def set_x0(self, x0: float) -> None:
         """
         Args:
@@ -479,7 +492,7 @@ class BodyXY(Body):
         """
         if not math.isfinite(x0):
             raise ValueError('x0 must be finite')
-        self._x0 = x0
+        self._x0 = float(x0)
         self._clear_cache()
 
     def get_x0(self) -> float:
@@ -499,7 +512,7 @@ class BodyXY(Body):
         """
         if not math.isfinite(y0):
             raise ValueError('y0 must be finite')
-        self._y0 = y0
+        self._y0 = float(y0)
         self._clear_cache()
 
     def get_y0(self) -> float:
@@ -521,7 +534,7 @@ class BodyXY(Body):
             raise ValueError('r0 must be finite')
         if not r0 > 0:
             raise ValueError('r0 must be greater than zero')
-        self._r0 = r0
+        self._r0 = float(r0)
         self._clear_cache()
 
     def get_r0(self) -> float:
@@ -532,7 +545,7 @@ class BodyXY(Body):
         return self._r0
 
     def _set_rotation_radians(self, rotation: float) -> None:
-        self._rotation_radians = rotation % (2 * np.pi)
+        self._rotation_radians = float(rotation % (2 * np.pi))
         self._clear_cache()
 
     def _get_rotation_radians(self) -> float:
@@ -648,6 +661,21 @@ class BodyXY(Body):
         """
         return self._cache.get('disc method', self._default_disc_method)
 
+    def add_arcsec_offset(self, dra_arcsec: float = 0, ddec_arcsec: float = 0) -> None:
+        """
+        Adjust the disc location `(x0, y0)` by applying offsets in arcseconds to the
+        RA/Dec celestial coordinates.
+
+        Args:
+            dra_arcsec: Offset in arcseconds in the positive right ascension direction.
+            ddec_arcsec: Offset in arcseconds in the positive declination direction.
+        """
+        dra = dra_arcsec / 3600
+        ddec = ddec_arcsec / 3600
+        ra0, dec0 = self.xy2radec(0, 0)
+        dx, dy = self.radec2xy(ra0 + dra, dec0 + ddec)
+        self.adjust_disc_params(dx=dx, dy=dy)
+
     # Illumination functions etc.
     def limb_xy(self, **kwargs) -> tuple[np.ndarray, np.ndarray]:
         """
@@ -836,6 +864,9 @@ class BodyXY(Body):
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
         label_poles: bool = True,
+        add_title: bool = True,
+        add_axis_labels: bool = True,
+        aspect_adjustable: Literal['box', 'datalim'] = 'box',
         **kwargs,
     ) -> Axes:
         """
@@ -848,37 +879,59 @@ class BodyXY(Body):
             show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
             label_poles: Toggle labelling the poles of the target body.
+            add_title: Add title generated by :func:`get_description` to the axis.
+            add_axis_labels: Add axis labels.
+            aspect_adjustable: Set `adjustable` parameter when setting the aspect ratio.
+                Passed to :func:`matplotlib.axes.Axes.set_aspect`.
             **kwargs: Additional arguments are passed to Matplotlib plotting functions
                 (useful for e.g. specifying `zorder`).
 
-
         Returns:
             The axis containing the plotted wireframe.
         """
         # Generate affine transformation from radec in degrees -> xy
         transform = self.matplotlib_radec2xy_transform()
         ax = self._plot_wireframe(
-            transform=transform, ax=ax, color=color, label_poles=label_poles, **kwargs
+            transform=transform,
+            ax=ax,
+            color=color,
+            label_poles=label_poles,
+            add_title=add_title,
+            **kwargs,
         )
 
         if self._test_if_img_size_valid():
             ax.set_xlim(-0.5, self._nx - 0.5)
             ax.set_ylim(-0.5, self._ny - 0.5)
-        ax.set_xlabel('x (pixels)')
-        ax.set_ylabel('y (pixels)')
-        ax.set_aspect(1, adjustable='box')
+        if add_axis_labels:
+            ax.set_xlabel('x (pixels)')
+            ax.set_ylabel('y (pixels)')
+        ax.set_aspect(1, adjustable=aspect_adjustable)
 
         if show:
             plt.show()
         return ax
 
     # Mapping
-    def map_img(self, img: np.ndarray, degree_interval: float = 1, warn_nan:bool=True) -> np.ndarray:
+    def map_img(
+        self,
+        img: np.ndarray,
+        degree_interval: float = 1,
+        interpolation: Literal['nearest', 'linear', 'quadratic', 'cubic'] = 'linear',
+        propagate_nan: bool = True,
+        warn_nan: bool = False,
+    ) -> np.ndarray:
         """
         Project an observed image onto a lon/lat grid.
 
-        The map projection is performed using `scipy.interpolate.RectBivariateSpline`
-        using linear interpolation (i.e. spline degrees `kx` and `ky` are set to 1).
+        If `interpolation` is `'linear'`, `'quadratic'` or `'cubic'`, the map projection
+        is performed using `scipy.interpolate.RectBivariateSpline` using the specified
+        degree of interpolation.
+
+        If `interpolation` is `'nearest'`, no interpolation is performed, and the mapped
+        image takes the value of the nearest pixel in the image to that location. This
+        can be useful to easily visualise the pixel scale for low spatial resolution
+        observations.
 
         Args:
             img: Observed image where pixel coordinates correspond to the `xy` pixel
@@ -886,7 +939,18 @@ class BodyXY(Body):
             degree_interval: Interval in degrees between the longitude/latitude points
                 in the mapped output. Passed to :func:`get_x_map` and :func:`get_y_map`
                 when generating the coordinates used for the projection.
-            warn_nan: Print warning if any values in `img` are NaN.
+            interpolation: Interpolation used when mapping. This can either any of
+                `'nearest'`, `'linear'`, `'quadratic'` or `'cubic'`. The default is
+                `'linear'`.
+            propagate_nan: If using spline interpolation, propagate NaN values from the
+                image to the mapped data. If `propagate_nan` is `True` (the default),
+                the interpolation is performed as normal (i.e. with NaN values in the
+                image set to 0), then any mapped locations where the nearest
+                corresponding image pixel is NaN are set to NaN. Note that there may
+                still be very small errors on the boundaries of NaN regions caused by
+                the interpolation.
+            warn_nan: Print warning if any values in `img` are NaN when any of the
+                spline interpolations are used.
 
         Returns:
             Array containing cylindrical map of the values in `img` at each location on
@@ -895,22 +959,69 @@ class BodyXY(Body):
         """
         x_map = self.get_x_map(degree_interval)
         y_map = self.get_y_map(degree_interval)
-        if np.any(np.isnan(img)):
-            if warn_nan:
-                print('Warning, image contains NaN values which will be set to 0')
-            img = np.nan_to_num(img)
-        interpolator = scipy.interpolate.RectBivariateSpline(
-            np.arange(img.shape[0]), np.arange(img.shape[1]), img, kx=1, ky=1
-        )
         projected = self._make_empty_map(degree_interval)
-        for a, b in self._iterate_image(projected.shape):
-            x = x_map[a, b]
-            if math.isnan(x):
-                continue
-            y = y_map[a, b]  # y should never be nan when x is not nan
-            projected[a, b] = interpolator(y, x)
+
+        spline_k = {
+            'linear': 1,
+            'quadratic': 2,
+            'cubic': 3,
+        }
+
+        if interpolation == 'nearest':
+            nan_sentinel = -999
+            x_map = np.asarray(
+                np.nan_to_num(np.round(x_map), nan=nan_sentinel), dtype=int
+            )
+            y_map = np.asarray(
+                np.nan_to_num(np.round(y_map), nan=nan_sentinel), dtype=int
+            )
+            for a, b in self._iterate_image(projected.shape):
+                x = x_map[a, b]
+                if x == nan_sentinel:
+                    continue
+                y = y_map[a, b]  # y should never be nan when x is not nan
+                projected[a, b] = img[y, x]
+        elif interpolation in spline_k:
+            k = spline_k[interpolation]
+            nans = np.isnan(img)
+            if np.any(np.isnan(img)):
+                if warn_nan:
+                    print('Warning, image contains NaN values which will be set to 0')
+                img = np.nan_to_num(img)
+            interpolator = scipy.interpolate.RectBivariateSpline(
+                np.arange(img.shape[0]), np.arange(img.shape[1]), img, kx=k, ky=k
+            )
+            for a, b in self._iterate_image(projected.shape):
+                x = x_map[a, b]
+                if math.isnan(x):
+                    continue
+                y = y_map[a, b]  # y should never be nan when x is not nan
+                if propagate_nan and self._should_propagate_nan_to_map(x, y, nans):
+                    continue
+                projected[a, b] = interpolator(y, x)
+        else:
+            raise ValueError(f'Unknown interpolation method {interpolation!r}')
         return projected
 
+    def _should_propagate_nan_to_map(
+        self, x: float, y: float, nans: np.ndarray
+    ) -> bool:
+        # Test if any of the four surrounding integer pixels in the image are NaN
+        x0 = max(math.floor(x), 0)
+        x1 = min(math.ceil(x), self._nx - 1)
+        y0 = max(math.floor(y), 0)
+        y1 = min(math.ceil(y), self._ny - 1)
+
+        return (
+            nans[y0, x0]
+            or nans[y0, x1]
+            or nans[y1, x0]
+            or nans[y1, x1]
+        )
+
+    def _xy_in_image_frame(self, x: float, y: float) -> bool:
+        return (-0.5 < x < self._nx - 0.5) and (-0.5 < y < self._ny - 0.5)
+
     # Backplane management
     @staticmethod
     def standardise_backplane_name(name: str) -> str:
@@ -1318,9 +1429,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of planetographic longitude values.
         """
@@ -1340,9 +1448,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of planetographic latitude values.
         """
@@ -1380,9 +1485,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of planetocentric longitude values.
         """
@@ -1402,9 +1504,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of planetocentric latitude values.
         """
@@ -1443,9 +1542,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of right ascension values as viewed by the
             observer. Locations which are not visible have a value of NaN.
@@ -1465,9 +1561,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of declination values as viewed by the
             observer. Locations which are not visible have a value of NaN.
@@ -1482,7 +1575,9 @@ class BodyXY(Body):
         for a, b in self._iterate_image(out.shape, progress=True):
             ra, dec = radec_map[a, b]
             if not math.isnan(ra):
-                out[a, b] = self.radec2xy(ra, dec)
+                x, y = self.radec2xy(ra, dec)
+                if self._xy_in_image_frame(x, y):
+                    out[a, b] = x, y
         return out
 
     def get_x_img(self) -> np.ndarray:
@@ -1501,13 +1596,10 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the x pixel coordinates each location
-            corresponds to in the observation. Locations which are not visible have a
-            value of NaN.
+            corresponds to in the observation. Locations which are not visible or are
+            not in the image frame have a value of NaN.
         """
         return self._get_xy_map(degree_interval)[:, :, 0]
 
@@ -1527,13 +1619,10 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the y pixel coordinates each location
-            corresponds to in the observation. Locations which are not visible have a
-            value of NaN.
+            corresponds to in the observation. Locations which are not visible or are
+            not in the image frame have a value of NaN.
         """
         return self._get_xy_map(degree_interval)[:, :, 1]
 
@@ -1569,9 +1658,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the phase angle value at each point on
             the target's surface.
@@ -1592,9 +1678,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the incidence angle value at each point
             on the target's surface.
@@ -1615,9 +1698,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the emission angle value at each point
             on the target's surface.
@@ -1637,7 +1717,6 @@ class BodyXY(Body):
         incidence_radians = np.deg2rad(self._get_illumination_gie_img()[:, :, 1])
         emission_radians = np.deg2rad(self._get_illumination_gie_img()[:, :, 2])
         with warnings.catch_warnings():
-            # TODO should we do this better?
             warnings.filterwarnings('ignore', 'divide by zero encountered in')
             warnings.filterwarnings('ignore', 'invalid value encountered in')
             azimuth_radians = self._azimuth_angle_from_gie_radians(
@@ -1650,9 +1729,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the azimuth angle value at each point
             on the target's surface.
@@ -1661,7 +1737,6 @@ class BodyXY(Body):
         incidence_radians = np.deg2rad(self._get_illumf_map(degree_interval)[:, :, 1])
         emission_radians = np.deg2rad(self._get_illumf_map(degree_interval)[:, :, 2])
         with warnings.catch_warnings():
-            # TODO should we do this better?
             warnings.filterwarnings('ignore', 'divide by zero encountered in')
             warnings.filterwarnings('ignore', 'invalid value encountered in')
             azimuth_radians = self._azimuth_angle_from_gie_radians(
@@ -1716,9 +1791,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the observer-target distance in km of
             each point on the target's surface.
@@ -1751,9 +1823,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the observer-target radial velocity in
             km/s of each point on the target's surface.
@@ -1783,9 +1852,6 @@ class BodyXY(Body):
         """
         See also :func:`get_backplane_map`.
 
-        Args:
-            degree_interval: Interval in degrees between points in the returned map.
-
         Returns:
             Array containing cylindrical map of the doppler factor of each point on the
             target's surface. This is calculated using
@@ -1796,6 +1862,129 @@ class BodyXY(Body):
             self.get_radial_velocity_map(degree_interval)
         )
 
+    @_cache_clearable_result
+    @progress_decorator
+    def _get_ring_plane_coordinate_imgs(
+        self,
+    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        radius_img = self._make_empty_img()
+        long_img = self._make_empty_img()
+        dist_img = self._make_empty_img()
+
+        ra_img = self.get_ra_img()
+        dec_img = self.get_dec_img()
+        for y, x in self._iterate_image(radius_img.shape, progress=True):
+            radius, long, dist = self.ring_plane_coordinates(
+                ra_img[y, x], dec_img[y, x], only_visible=False
+            )
+            radius_img[y, x] = radius
+            long_img[y, x] = long
+            dist_img[y, x] = dist
+
+        hidden_img = dist_img > self.get_distance_img()
+        radius_img[hidden_img] = np.nan
+        long_img[hidden_img] = np.nan
+        dist_img[hidden_img] = np.nan
+        return radius_img, long_img, dist_img
+
+    @_cache_stable_result
+    @progress_decorator
+    def _get_ring_plane_coordinate_maps(
+        self, degree_interval: float
+    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        radius_map = self._make_empty_map(degree_interval)
+        long_map = self._make_empty_map(degree_interval)
+        dist_map = self._make_empty_map(degree_interval)
+
+        visible = self._get_illumf_map(degree_interval)[:, :, 4]
+        ra_map = self.get_ra_map(degree_interval)
+        dec_map = self.get_dec_map(degree_interval)
+        for a, b, targvec in self._enumerate_targvec_map(
+            degree_interval, progress=True
+        ):
+            if visible[a, b]:
+                radius, long, dist = self.ring_plane_coordinates(
+                    ra_map[a, b], dec_map[a, b], only_visible=False
+                )
+                radius_map[a, b] = radius
+                long_map[a, b] = long
+                dist_map[a, b] = dist
+
+        hidden_map = dist_map > self.get_distance_map(degree_interval)
+        radius_map[hidden_map] = np.nan
+        long_map[hidden_map] = np.nan
+        dist_map[hidden_map] = np.nan
+        return radius_map, long_map, dist_map
+
+    def get_ring_plane_radius_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the ring plane radius in km for each pixel in the image,
+            calculated using :func:`Body.ring_plane_coordinates`. Points of the ring
+            plane obscured by the target body have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_imgs()[0]
+
+    def get_ring_plane_radius_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Returns:
+            Array containing cylindrical map of the ring plane radius in km obscuring
+            each point on the target's surface, calculated using
+            :func:`Body.ring_plane_coordinates`. Points where the target body is
+            unobscured by the ring plane have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_maps(degree_interval)[0]
+
+    def get_ring_plane_longitude_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the ring plane planetographic longitude in degrees for each
+            pixel in the image, calculated using :func:`Body.ring_plane_coordinates`.
+            Points of the ring plane obscured by the target body have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_imgs()[1]
+
+    def get_ring_plane_longitude_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Returns:
+            Array containing cylindrical map of the ring plane planetographic longitude
+            in degrees obscuring each point on the target's surface, calculated using
+            :func:`Body.ring_plane_coordinates`. Points where the target body is
+            unobscured by the ring plane have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_maps(degree_interval)[1]
+
+    def get_ring_plane_distance_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the ring plane distance from the observer in km for each
+            pixel in the image, calculated using :func:`Body.ring_plane_coordinates`.
+            Points of the ring plane obscured by the target body have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_imgs()[2]
+
+    def get_ring_plane_distance_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Returns:
+            Array containing cylindrical map of the ring plane distance from the
+            observer in km obscuring each point on the target's surface, calculated
+            using  :func:`Body.ring_plane_coordinates`. Points where the target body is
+            unobscured by the ring plane have a value of NaN.
+        """
+        return self._get_ring_plane_coordinate_maps(degree_interval)[2]
+
     # Default backplane registration
     def _register_default_backplanes(self) -> None:
         self.register_backplane(
@@ -1890,6 +2079,24 @@ class BodyXY(Body):
             self.get_doppler_img,
             self.get_doppler_map,
         )
+        self.register_backplane(
+            'RING-RADIUS',
+            'Equatorial (ring) plane radius [km]',
+            self.get_ring_plane_radius_img,
+            self.get_ring_plane_radius_map,
+        )
+        self.register_backplane(
+            'RING-LON-GRAPHIC',
+            'Equatorial (ring) plane planetographic longitude [deg]',
+            self.get_ring_plane_longitude_img,
+            self.get_ring_plane_longitude_map,
+        )
+        self.register_backplane(
+            'RING-DISTANCE',
+            'Equatorial (ring) plane distance to observer [km]',
+            self.get_ring_plane_distance_img,
+            self.get_ring_plane_distance_map,
+        )
 
 
 class BackplaneNotFoundError(Exception):
