@@ -1,6 +1,7 @@
 from functools import wraps
 from typing import TypeVar, ParamSpec, Concatenate, Callable, TYPE_CHECKING
 import tqdm
+import time
 
 if TYPE_CHECKING:
     from .base import SpiceBase
@@ -69,6 +70,31 @@ class CLIProgressHook(ProgressHook):
             self.bars[key].close()
 
 
+class TotalTimingProgressHook(ProgressHook):
+    """
+    Progress hook to log time spent in each function.
+    """
+
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.start_times: dict[tuple[str, ...], float] = {}
+        self.self_durations: dict[tuple[str, ...], float] = {}
+
+    def __call__(self, progress: float, stack: list[str]) -> None:
+        key = tuple(stack)
+        if key not in self.start_times:
+            self.start_times[key] = time.time()
+        if progress == 1:
+            full_diration = time.time() - self.start_times[key]
+            self_duration = full_diration
+            for k, v in self.self_durations.items():
+                if len(k) > len(key) and k[: len(key)] == key:
+                    self_duration -= self.self_durations[k]
+            self.self_durations[key] = self_duration
+            desc = '> ' * (len(key) - 1) + key[-1]
+            print(f'{full_diration:5.2f} {self_duration:5.2f}  {desc}')
+
+
 # Specific progress hooks for use in saving
 class SaveProgressHook(ProgressHook):
     """
@@ -130,6 +156,7 @@ class SaveNavProgressHook(SaveProgressHook):
             'BodyXY._get_illumination_gie_img': 50,
             'BodyXY._get_state_imgs': 30,
             'BodyXY.get_radial_velocity_img': 5,
+            'BodyXY._get_ring_coordinate_imgs': 50,
             'Observation.save_observation': 100,
         }
         self.default_key = 'Observation.save_observation'
@@ -143,7 +170,7 @@ class SaveMapProgressHook(SaveProgressHook):
         super().__init__(*args, **kwargs)
         self.n_wavelengths = n_wavelengths
         self.weights: dict[str, float] = {
-            'Observation.get_mapped_data': n_wavelengths * 5,
+            'Observation._get_mapped_data': n_wavelengths * 5,
             'BodyXY._get_targvec_map': 1,
             'BodyXY._get_illumf_map': 5,
             'BodyXY._get_radec_map': 10,
@@ -151,6 +178,7 @@ class SaveMapProgressHook(SaveProgressHook):
             'BodyXY._get_lonlat_map': 10,
             'BodyXY._get_lonlat_centric_map': 5,
             'BodyXY._get_state_maps': 5,
+            'BodyXY._get_ring_coordinate_maps': 10,
             'Observation.save_mapped_observation': 20,
         }
         self.default_key = 'Observation.save_mapped_observation'
